/*
Copyright (©) 2003-2022 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


#pragma once

#include <config/libraries.h>

class Database_UserResources
{
public:
  static std::vector <std::string> names ();
  static void remove (const std::string& name);
  static std::string url (const std::string& name);
  static void url (const std::string& name, const std::string & value);
  static std::string book (const std::string& name, int id);
  static void book (const std::string& name, int id, const std::string & fragment);
private:
  static std::string folder ();
  static std::string fragment ();
  static std::string file (const std::string& name);
  static std::string load (const std::string & name, size_t offset);
  static void save (const std::string & name, size_t offset, const std::string & value);
};
